

********************************************************************************
/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
/*--------------Econ 338 -- Stata Presentation Winter 2021--------------------*/
/*~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~*/
********************************************************************************

clear all
set more off
*cap log close


/*****************************************************************

   1. Organize the workplace.

*****************************************************************/

*****  Way1 : set to directory where  the date is stored
cd "C:\Users\yaya1\Dropbox\Fall2020\ECON338\Stata Conference\Conference 1"

*open your dataset
use data_presentation.dta

use data_presentation.dta,clear

*Open excel file
*clear
*import excel data_presentation.xls, sheet("Data1") firstrow 


/*
** Way 2: set the directory

global path ":\Users\yaya1\Dropbox\Fall2020\ECON338\Stata Conference\Conference 1"
use "$path\data_presentation.dta"

*/

*** Format 
format famsize hlth age yedu nwhite %3.2f
format incfam07on %16.2f

***first look
browse
list year age marstat sex famsize educ in 2/10

** Describe data contents

codebook age sex

**Summary 
summarize

** Summary Statistics for all
summarize age

**Select for Male

summarize age if sex==1
summarize age if sex==2

summarize age if famsize==2


** way1 : select our sample 
keep if age>=26 & age<=59 & marradult==1


** way2 : select our sample 
gen sample = ( age>=26 & age<=59 & marradult==1)
keep if sample==1


*** rename variables
rename hlth health

rename incfam07on inc_quintiles

*way 1: Modify some variables
gen hi_2= uninsured==2
tab hi_2

*way 2: Modify some variables
rename uninsured hi
replace hi=0 if hi==1
replace hi=1 if hi==2

tab hi hi_2

* Variable and value labels

label var hi "Health Insurance coverage status"
label define hilb 0 "Not covered", modify
label define hilb 1 "Covered", modify
label values hi hilb


label var health "Health status"
label define healthlb 1 "Poor", modify
label define healthlb 2 "Fair", modify
label define healthlb 3 "Good", modify
label define healthlb 4 "Very Good", modify
label define healthlb 5 "Excellent", modify
label values health healthlb


*Generate new variables (remember that we should label them too)

gen age2=age^2

gen young_inc=.
replace young_inc=1 if inc_quintiles==0 & age<=30
replace young_inc=2 if inc_quintiles==1 & age<=30
replace young_inc=3 if inc_quintiles==2 & age<=30
replace young_inc=4 if inc_quintiles==3 & age<=30
replace young_inc=5 if inc_quintiles==4 & age<=30


* descriptive statistics

tab inc_quintiles

tab hi

table hi , c(mean health) 

** Same results
table hi , c(mean health sd health) 
tab hi, sum(health)

tab hi health

tab hi sex

tab fem ms, cell

**  histogram
hist health if hi==1, discrete title("insured")
graph export "C:\Users\yaya1\Dropbox\Fall2020\ECON338\Stata Conference\Conference 1\Graph\hhealthhi.pdf", as(pdf) replace


hist health if hi==0, discrete title("not insured")
graph export "/Users/mayssun/Documents/Econometrics Public Policy/stata/mastering_metrics/NHIS2009/hhealthnhi.pdf", as(pdf) replace


hist health if inc_quintiles==1, discrete title("Poor")
graph export "/Users/mayssun/Documents/Econometrics Public Policy/stata/mastering_metrics/NHIS2009/hhealthpoor.pdf", as(pdf) replace

hist health if inc_quintiles==5, discrete title("Rich")
graph export "/Users/mayssun/Documents/Econometrics Public Policy/stata/mastering_metrics/NHIS2009/hhealthrich.pdf", as(pdf) replace


hist health if yedu<12, discrete title("Less than high school")
graph export "/Users/mayssun/Documents/Econometrics Public Policy/stata/mastering_metrics/NHIS2009/hhealthloweduc.pdf", as(pdf) replace

hist health if yedu>=16, discrete discrete title("College or more")
graph export "/Users/mayssun/Documents/Econometrics Public Policy/stata/mastering_metrics/NHIS2009/hhealthhigheduc.pdf", as(pdf) replace

** graph bar

graph bar (mean) hi, over(health)

** Table of stats

table hi, c(mean health mean inc mean age mean yedu mean famsize)

** Correlations of variables

pwcorr health yedu inc famsize hi

* run a linear regression model
regress health hi yedu inc famsize age


